@@ -1,7 +1,7 @@
 package App::lcpan;
 
-our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2015-08-11'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1893,7 +1893,7 @@ sub _get_prereqs {
   rel,
   version
 FROM dep dp
-WHERE dp.dist_id IN (".join(",",@dist_ids).")
+WHERE dp.dist_id IN (".join(",",grep {defined} @dist_ids).")
 ORDER BY module".($level > 1 ? " DESC" : ""));
     $sth->execute;
     my @res;
@@ -2362,7 +2362,7 @@ App::lcpan - Manage your local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.47 of App::lcpan (from Perl distribution App-lcpan), released on 2015-07-27.
+This document describes version 0.48 of App::lcpan (from Perl distribution App-lcpan), released on 2015-08-11.
 
 =head1 SYNOPSIS
 
